
 /********************************************************************************
// Title:		sip_przyklad1.c  
 
// Created on:	2018-08-25 at 12:03:38 by Andrzej Majkowski.
// Copyright:	Politechnika Warszawska. All Rights Reserved.
********************************************************************************/


#include <userint.h>
#include "sip_przyklad1.h"
#include <analysis.h>
#define NUMELEM 1024
#define ORDER 5
 

static int panelHandle;
int i=0;  				   
const int order=ORDER;     //rzd filtra
double phase=0.0;	  	   //faza sygnau sinusoidalnego
double noise[NUMELEM];	   //szum biay
double clipnoise[NUMELEM]; //szum biay obcity do <150Hz
double sine[NUMELEM]; 	   //sygna sinusoidalny
double dirty[NUMELEM];	   //zaszumiony sygna sinusoidalny
double clean[NUMELEM];	   //przefiltrowany sygna sinusoidalny
double x1[ORDER+1];		   //warunki graniczne dla filtra IIR
double y1[ORDER+1];		   //"
double b[ORDER+1];		   //wspczynniki filtra IIR
double a[ORDER+1];		   //"



int main (int argc, char *argv[])
{

	if (InitCVIRTE (0, argv, 0) == 0)
		return -1;	//brak pamieci 
	if ((panelHandle = LoadPanel (0, "sip_przyklad1.uir", MPANEL)) < 0)
		return -1;
	DisplayPanel (panelHandle);
	RunUserInterface ();
	DiscardPanel (panelHandle);
	
	return 0;
}



int CVICALLBACK start (int panel, int control, int event,
					   void *callbackData, int eventData1, int eventData2)
{
	switch (event)
	{
		case EVENT_COMMIT:
			
			{
			
			WhiteNoise (NUMELEM, 1.0, 100, noise);  //Generacja szumu biaego
			
			
			//Obliczenie wspczynnikw BW (tablice a i b) dla filtra IIR grnoprzepustowego 150 Hz
			Bw_Coef (HIGHPASS, order, 1024, 150, 0, a, order+1, b, order+1);
	
			//Warunki graniczne dla filtra IIR, zakadamy, e nie znamy systemu, ustawiamy na 0.0
			for (i=0;i<(ORDER+1);i++) {
				y1[i]=0.0;
				x1[i]=0.0;
			}

			//Zastosowanie filtra grnoprzepustowego BW (150 Hz) do szumu
			IIRFiltering (noise, NUMELEM, a, y1, order+1, b, x1, order+1, clipnoise);
	
			SineWave (NUMELEM, 1.0, 7.8125e-3, &phase, sine);  //Generate a Sine wave
	
			//Dodanie przefiltrowannego szumu do sinusoidy
			Add1D (sine, clipnoise, NUMELEM, dirty);
	
			//Wykrelenie zaszumionej sinusoidy
			PlotWaveform (panelHandle, MPANEL_GRAPH1, dirty,
							  NUMELEM, VAL_DOUBLE, 1.0, 0.0, 0.0,
							  1, VAL_THIN_LINE, VAL_EMPTY_SQUARE,
							  VAL_SOLID, 1, VAL_YELLOW);
	

			}
			
			break;
	}
	return 0;
}



int CVICALLBACK filtruj (int panel, int control, int event,
						 void *callbackData, int eventData1, int eventData2)
{
	switch (event)
	{
		case EVENT_COMMIT:
			
			{
			
			//Obliczenie wspczynnikw filtra dolnoprzepustowego (25Hz)
			Bw_Coef (LOWPASS, order, 1024, 25, 0, a, order+1, b, order+1);
	
			//x1 i y1 zawieraj warunki graniczne dla zastosowanego powyej filtra IIR
			for (i=0;i<(ORDER+1);i++) {
				y1[i]=0.0;
				x1[i]=0.0;
			}
	
			//Zastosowanie filtra
			IIRFiltering (dirty, NUMELEM, a, y1, order+1, b, x1, order+1, clean);
			
			//Wykrelenie przefiltrowanej sinusoidy
	
			PlotWaveform (panelHandle, MPANEL_GRAPH2, clean,
							  NUMELEM, VAL_DOUBLE, 1.0, 0.0, 0.0,
							  1, VAL_THIN_LINE, VAL_EMPTY_SQUARE,
							  VAL_SOLID, 1, VAL_YELLOW);
			}

			break;
	}
	return 0;
}



int CVICALLBACK quit (int panel, int control, int event,
					  void *callbackData, int eventData1, int eventData2)
{
	switch (event)
	{
		case EVENT_COMMIT:
			
			QuitUserInterface(0);

			break;
	}
	return 0;
}

